@@ -1,4 +1,4 @@
-# .. Copyright (C) 2012-2019 Bryan A. Jones.
+# .. Copyright (C) 2012-2020 Bryan A. Jones.
 #
 #    This file is part of CodeChat.
 #
@@ -27,17 +27,30 @@
 # These are listed in the order prescribed by `PEP 8
 # <http://www.python.org/dev/peps/pep-0008/#imports>`_.
 #
+# Standard library
+# ----------------
+# None
+#
 # Third-party imports
 # -------------------
 from pygments.lexers import get_all_lexers
 
+# Local application imports
+# -------------------------
+# None.
+
+
 # Supported languages
 # ===================
 # Based on the unique name for each lexer, provide some additional information
 # on comment delimiters that Pygments doesn't explicitly define. This data was
 # mostly taken from the `Wikipedia page
 # <http://en.wikipedia.org/wiki/Comparison_of_programming_languages_(syntax)#Comments>`_.
+#
+# `Disable Black <https://github.com/psf/black#the-black-code-style>`_ for this block.
+# fmt: off
 COMMENT_DELIMITER_INFO = {
+#
 # These languages have unit tests which pass
 # ------------------------------------------
 # See :doc:`../test/CodeToRest_test.py` for the tests.
@@ -74,6 +87,7 @@ COMMENT_DELIMITER_INFO = {
     "Vala":           ( ( "//", ),     "/*",            "*/"),
     "Zephir":         ( ( "//", ),     "/*",            "*/"),
     "Haxe":           ( ( "//", ),     "/*",            "*/"),
+    "Thrift":         ( ( "//", ),     "/*",            "*/"),
 
     "PHP":            ( ( "#", "//"),  "/*",            "*/"),
     # Block comments not tested.
@@ -129,7 +143,7 @@ COMMENT_DELIMITER_INFO = {
     "RPMSpec":        ( ( "#", ),        "",              ""),
     "Nimrod":         ( ( "#", ),        "",              ""),
     # Comments continued on the next line with a ``\`` aren"t supported.
-    "NSIS":           ( ("#", ";"),    "",              ""),
+    "NSIS":           ( ("#", ";"),      "",              ""),
     "TeX":            ( ( "%", ),        "",              ""),
     "Erlang":         ( ( "%", ),        "",              ""),
     "QBasic":         ( ( "'", ),        "",              ""),
@@ -144,10 +158,15 @@ COMMENT_DELIMITER_INFO = {
     "COBOL":          ( ( "      *", ),  "",              ""),
     "YAML":           ( ( "#", ),        "",              ""),
 
+# These languages lack unit tests
+# -------------------------------
+"HTML+Django/Jinja": ( ( "", ),  "<!--",           "-->"),
+
 # These languages have failing unit tests
 # ---------------------------------------
 # None at this time.
 }
+# fmt: on
 
 # Supported extensions
 # ====================
